import { Highlighter, HighlighterOptions } from 'shiki';

type ShakuDirectiveUnderline = {
    type: "DirectiveUnderline";
    config: {
        style: "solid" | "dotted" | "wavy";
        content: string;
        offset: number;
    };
};
type ShakuAnnotationLine = {
    type: "AnnotationLine";
    config: {
        offset: number;
        content: string;
    };
};
type ShakuDirectiveCallout = {
    type: "DirectiveCallout";
    config: {
        offset: number;
    };
};
type ShakuDirectiveCollapse = {
    type: "DirectiveCollapse";
    config: {
        offset: number;
        mark: "start" | "end";
    };
};
type ShakuDirectiveHighlight = {
    type: "DirectiveHighlight";
    config: {
        mark: "start" | "end" | "below";
    };
};
type ShakuDirectiveDim = {
    type: "DirectiveDim";
    config: {
        mark: "start" | "end" | "below";
    };
};
type ShakuDirectiveFocus = {
    type: "DirectiveFocus";
    config: {
        mark: "start" | "end" | "below";
    };
};
type ShakuLine = ShakuDirectiveUnderline | ShakuAnnotationLine | ShakuDirectiveCallout | ShakuDirectiveCollapse | ShakuDirectiveHighlight | ShakuDirectiveDim | ShakuDirectiveFocus;
declare const parseLine: (line: string) => ShakuLine | null;
declare function shouldApplyAnnotation(meta: string): boolean;
/**
 * Thought we process by lines, but we need to render in blocks, for instance:
 * A full callout normally contains:
 * 1. DirectiveCallout
 * 2. one or more AnnotationLine
 *
 * An underline annotation contains:
 * 1. DirectiveUnderline
 * 2. one ore more AnnotationLine
 *
 * DirectiveCollapse also render a few lines of source code
 * So this function should render component
 */
type ShakuComponentCallout = {
    type: "ShakuComponentCallout";
    config: {
        offset: number;
        arrowOffset: number;
        /** restricted raw html */
        contents: string;
    };
};
type ShakuComponentUnderline = {
    type: "ShakuComponentUnderline";
    config: {
        offset: number;
        underlineOffset: number;
        underlineContent: string;
        underlineStyle: "solid" | "dotted" | "wavy";
        /** restricted raw html */
        contents: string;
    };
};
type ShakuComponent = ShakuComponentCallout | ShakuComponentUnderline;
declare function renderComponent(component: ShakuComponent): string | undefined;

declare const defaultCode: {
    abap: string;
    "actionscript-3": string;
    ada: string;
    apache: string;
    apex: string;
    apl: string;
    applescript: string;
    ara: string;
    astro: string;
    awk: string;
    ballerina: string;
    batch: string;
    berry: string;
    bicep: string;
    blade: string;
    cadence: string;
    clarity: string;
    clojure: string;
    cmake: string;
    asm: string;
    c: string;
    cobol: string;
    coffee: string;
    crystal: string;
    css: string;
    cue: string;
    d: string;
    dart: string;
    dax: string;
    dockerfile: string;
    "dream-maker": string;
    elixir: string;
    elm: string;
    erb: string;
    erlang: string;
    fish: string;
    "f#": string;
    "git-commit": string;
    glsl: string;
    gnuplot: string;
    graphql: string;
    groovy: string;
    hack: string;
    haml: string;
    handlebars: string;
    haskell: string;
    hcl: string;
    hlsl: string;
    html: string;
    cpp: string;
    "c#": string;
    go: string;
    java: string;
    javascript: string;
    imba: string;
    ini: string;
    properties: string;
    jison: string;
    json: string;
    json5: string;
    jsonc: string;
    jsonnet: string;
    jssm: string;
    jsx: string;
    kotlin: string;
    kusto: string;
    kql: string;
    julia: string;
    matlab: string;
    latex: string;
    less: string;
    liquid: string;
    php: string;
    lisp: string;
    logo: string;
    lua: string;
    make: string;
    makefile: string;
    markdown: string;
    marko: string;
    mdx: string;
    mermaid: string;
    nginx: string;
    nim: string;
    nix: string;
    objc: string;
    ocaml: string;
    pascal: string;
    perl: string;
    powerquery: string;
    powershell: string;
    prisma: string;
    prolog: string;
    proto: string;
    plsql: string;
    purescript: string;
    raku: string;
    perl6: string;
    razor: string;
    reg: string;
    rel: string;
    riscv: string;
    sas: string;
    sass: string;
    scala: string;
    scheme: string;
    shaderlab: string;
    scss: string;
    shader: string;
    shellscript: string;
    bash: string;
    shell: string;
    zsh: string;
    smalltalk: string;
    solidity: string;
    r: string;
    sparql: string;
    "ssh-config": string;
    stata: string;
    stylus: string;
    svelte: string;
    python: string;
    ruby: string;
    rust: string;
    sql: string;
    "system-verilog": string;
    tcl: string;
    tex: string;
    toml: string;
    tsx: string;
    turtle: string;
    swift: string;
    twig: string;
    typescript: string;
    vb: string;
    verilog: string;
    vhdl: string;
    viml: string;
    vimscript: string;
    vue: string;
    wasm: string;
    wenyan: string;
    wgsl: string;
    wolfram: string;
    xml: string;
    xsl: string;
    yaml: string;
    zenscript: string;
};
declare const supportedLangs: string[];

declare let codeToShakuHtml: (this: ShakuHighlighter, { code, meta, parseBasicMarkdown, options, }: {
    code: string;
    meta: string;
    parseBasicMarkdown: (md: string) => string;
    options: Parameters<Highlighter["codeToHtml"]>[1];
}) => {
    skipped: boolean;
    html: string;
};

interface ShakuHighlighter extends Highlighter {
    codeToShakuHtml: typeof codeToShakuHtml;
    fallbackToShiki?: boolean;
}
type ShakuHighlighterOptions = HighlighterOptions & {
    fallbackToShiki?: boolean;
};
declare function getShakuHighlighters(options: ShakuHighlighterOptions): Promise<ShakuHighlighter[]>;

export { ShakuHighlighterOptions, defaultCode, getShakuHighlighters, parseLine, renderComponent, shouldApplyAnnotation, supportedLangs };
